# UtilsRxPY

## Documentation

Refer to the [API docs](https://carsten-leue.github.io/UtilsRxPY/)

## Build Setup

[![Build Status](https://www.travis-ci.com/Carsten-Leue/UtilsRxPY.svg?branch=main)](https://www.travis-ci.com/Carsten-Leue/UtilsRxPY)
